pub struct InterleavedComplexArray<T, P> { /* private fields */ }Implementations
Sourceimpl<T> InterleavedComplexArray<T, MxArray>where
T: MatlabNumber,
impl<T> InterleavedComplexArray<T, MxArray>where
T: MatlabNumber,
Methods from Deref<Target = mxArray_tag>
Sourcepub fn duplicate(&self) -> MxArray
pub fn duplicate(&self) -> MxArray
Create a deep copy of the array, and return as an owned type. However,
consider using MatlabClass::duplicate instead if you are already working
with MatlabClasses.
Sourcepub fn dimensions(&self) -> &[usize]
pub fn dimensions(&self) -> &[usize]
Return the sizes of the constituent dimensions of the mxArray
Sourcepub fn raw_class_id(&self) -> u32
pub fn raw_class_id(&self) -> u32
Return the raw class ID; the number Matlab returns.
Sourcepub fn class_id(&self) -> Result<ClassID, u32>
pub fn class_id(&self) -> Result<ClassID, u32>
Return Ok(ClassID) for mxArrays which map to a built-in class (such as
numeric arrays, structure arrays, and cell arrays (see ClassID);
otherwise it returns the raw class ID in the Err variant. These other
values of the raw class ID are used in modern versions of Matlab for custom
classes, defined via e..g classdef.
Sourcepub fn is_complex(&self) -> bool
pub fn is_complex(&self) -> bool
Check whether the backing array is complex. Since the only arrays which can be complex are numeric arrays, this also implies that.
pub fn complexity(&self) -> Complexity