pub enum WorkSpace {
Base,
Caller,
Global,
}Expand description
Possible workspaces to put your variable
Variants
Base
The base workspace, i.e. the command prompt.
Caller
The workspace formed by the callframe of the function that called this MEX
function. Equivalent to Base if called from the command prompt.
Global
The workspace with all the global variables.